<?php

declare(strict_types=1);

use function apexl\io\env;

return [
    'drivers' => [
        'sms' => [
            'twilio' => [
                'sid' => env('NOTIFIER_TWILIO_SID'),
                'token' => env('NOTIFIER_TWILIO_TOKEN'),
                'from' => env('NOTIFIER_TWILIO_FROM'),
            ],
        ],
    ],
];
