<?php

declare(strict_types=1);

use Apexl\Io\NotifierTwilio\Dtos\TwilioConfigDto;
use Apexl\Io\NotifierTwilio\Factories\TwilioClientFactory;
use Twilio\Rest\Client;
use function DI\factory;

return [
    Client::class => factory(fn(TwilioClientFactory $factory) => $factory->make()),
    TwilioConfigDto::class => factory(fn() => TwilioConfigDto::fromConfig()),
];